@@ -4,14 +4,14 @@ use ockam_core::compat::{
     string::{String, ToString},
     vec::Vec,
 };
-use ockam_core::Result;
-use ockam_core::{async_trait, compat::boxed::Box};
-use ockam_key_exchange_core::{CompletedKeyExchange, KeyExchanger};
-use ockam_vault_core::Signature as GenericSignature;
-use ockam_vault_core::{
+use ockam_core::vault::Signature as GenericSignature;
+use ockam_core::vault::{
     Secret, SecretAttributes, SecretPersistence, SecretType, AES256_SECRET_LENGTH,
     CURVE25519_SECRET_LENGTH,
 };
+use ockam_core::Result;
+use ockam_core::{async_trait, compat::boxed::Box};
+use ockam_key_exchange_core::{CompletedKeyExchange, KeyExchanger};
 
 #[derive(Debug, Clone, Copy)]
 enum InitiatorState {
@@ -46,7 +46,7 @@ impl<V: X3dhVault> Initiator<V> {
     async fn prologue(&mut self) -> Result<()> {
         if self.identity_key.is_none() {
             let p_atts = SecretAttributes::new(
-                SecretType::Curve25519,
+                SecretType::X25519,
                 SecretPersistence::Persistent,
                 CURVE25519_SECRET_LENGTH,
             );
@@ -87,7 +87,7 @@ impl<V: X3dhVault> KeyExchanger for Initiator<V> {
                 let ephemeral_identity_key = self
                     .vault
                     .secret_generate(SecretAttributes::new(
-                        SecretType::Curve25519,
+                        SecretType::X25519,
                         SecretPersistence::Ephemeral,
                         CURVE25519_SECRET_LENGTH,
                     ))
